@@ -34,7 +34,7 @@ from Crypto import Random
 from Crypto.Util import Counter
 
 from .crc64_combine import mkCombineFun
-from .compat import to_string, to_bytes
+from .compat import to_string, to_bytes, urlparse
 from .exceptions import ClientError, InconsistentError, RequestError, OpenApiFormatError
 from . import defaults
 
@@ -148,6 +148,17 @@ def is_valid_bucket_name(name):
 
     return set(name) <= _BUCKET_NAME_CHARS
 
+def is_valid_endpoint(endpoint):
+    """判断是否为合法的endpoint"""
+    if endpoint is None:
+        return False
+
+    pattern = '^([a-zA-Z]+://)?[\w.-]+(:\d+)?$'
+    if re.match(pattern, endpoint):
+        return True
+
+    return False
+
 def change_endianness_if_needed(bytes_array):
     if sys.byteorder == 'little':
         bytes_array.reverse();
@@ -405,7 +416,7 @@ class _FileLikeAdapter(object):
         if not content:
             self.read_all = True
             _invoke_progress_callback(self.progress_callback, self.offset, None)
-            return ''
+            return to_bytes('')
         else:
             _invoke_progress_callback(self.progress_callback, self.offset, None)
 
@@ -477,7 +488,7 @@ class _BytesAndFileAdapter(object):
 
     def read(self, amt=None):
         if self.offset >= self.size:
-            return ''
+            return to_bytes('')
 
         if amt is None or amt < 0:
             bytes_to_read = self.size - self.offset
